## Slice Sampling
Slice sampling is a non-deterministic method used to sample from arbitrary curves. Specifically slice sampling belongs to the family of Markov chain Monte-Carlo (McMC) methods. The general principle behind such methods is to construct a Markov chain that has the desired distribution as an equilibrium solution. They are used to obtain numeric approximations from multi-dimensional integrals for which no closed-form solution is readily available. We can then use the samples to construct estimations of statistics on the underlying distribution (mean, mode, variance etc.) by simply calculating the equivalent sample-statistic. 

Slice sampling in particular possesses several very desirable properties \cite{murray2009elliptical}. It allows us to sample from integrals that are _proportional_ to our underlying distribution. There is no assumption that our probability mass sums to one. Consequently our intractable denominator above is of no concern -- we simply proceed using the scaled posterior.

Additionally, slice sampling has no free parameters. This is useful from a practical perspective, as it removes the need to spend time tuning and updating hyper-parameters for more complex models. It also impacts on performance; the more general Metropolis-Hastings model is highly sensitive to step-size parameters, which means unless we get it right we're going to perform very poorly on evaluation. In contrast, slice sampling adjusts the step-size to match the local shape of the density function. There are several modified slice-samplers which are heavily parallelisable \cite{Tran_2015}.

In our analysis we use the following slice-sampling algorithm, iteratively tuning on each subsequent weight-parameter. In some sense this is analogous to the iterative processing present in stochastic gradient descent.

